==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/SyntaxHighlightType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SyntaxHighlightType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SyntaxHighlightType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="fontSize" type="{http://www.w3.org/2001/XMLSchema}string" default="10px" /&gt;
 *       &lt;attribute name="fontOrigin" type="{http://schema.webpdf.de/1.0/operation}FontOriginModeType" default="system" /&gt;
 *       &lt;attribute name="fontFamily" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="wordBreak" type="{http://schema.webpdf.de/1.0/operation}TextWrapModeType" default="auto" /&gt;
 *       &lt;attribute name="lineNumbers" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="lineHeight" type="{http://www.w3.org/2001/XMLSchema}string" default="12px" /&gt;
 *       &lt;attribute name="language" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="available" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="relevance" type="{http://www.w3.org/2001/XMLSchema}int" default="90" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SyntaxHighlightType")
public class SyntaxHighlightType {

    @XmlAttribute(name = "fontSize")
    protected String fontSize;
    @XmlAttribute(name = "fontOrigin")
    protected FontOriginModeType fontOrigin;
    @XmlAttribute(name = "fontFamily")
    protected String fontFamily;
    @XmlAttribute(name = "wordBreak")
    protected TextWrapModeType wordBreak;
    @XmlAttribute(name = "lineNumbers")
    protected Boolean lineNumbers;
    @XmlAttribute(name = "lineHeight")
    protected String lineHeight;
    @XmlAttribute(name = "language")
    protected String language;
    @XmlAttribute(name = "available")
    protected String available;
    @XmlAttribute(name = "relevance")
    protected Integer relevance;

    /**
     * Gets the value of the fontSize property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFontSize() {
        if (fontSize == null) {
            return "10px";
        } else {
            return fontSize;
        }
    }

    /**
     * Sets the value of the fontSize property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFontSize(String value) {
        this.fontSize = value;
    }

    public boolean isSetFontSize() {
        return (this.fontSize!= null);
    }

    /**
     * Gets the value of the fontOrigin property.
     * 
     * @return
     *     possible object is
     *     {@link FontOriginModeType }
     *     
     */
    public FontOriginModeType getFontOrigin() {
        if (fontOrigin == null) {
            return FontOriginModeType.SYSTEM;
        } else {
            return fontOrigin;
        }
    }

    /**
     * Sets the value of the fontOrigin property.
     * 
     * @param value
     *     allowed object is
     *     {@link FontOriginModeType }
     *     
     */
    public void setFontOrigin(FontOriginModeType value) {
        this.fontOrigin = value;
    }

    public boolean isSetFontOrigin() {
        return (this.fontOrigin!= null);
    }

    /**
     * Gets the value of the fontFamily property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFontFamily() {
        if (fontFamily == null) {
            return "";
        } else {
            return fontFamily;
        }
    }

    /**
     * Sets the value of the fontFamily property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFontFamily(String value) {
        this.fontFamily = value;
    }

    public boolean isSetFontFamily() {
        return (this.fontFamily!= null);
    }

    /**
     * Gets the value of the wordBreak property.
     * 
     * @return
     *     possible object is
     *     {@link TextWrapModeType }
     *     
     */
    public TextWrapModeType getWordBreak() {
        if (wordBreak == null) {
            return TextWrapModeType.AUTO;
        } else {
            return wordBreak;
        }
    }

    /**
     * Sets the value of the wordBreak property.
     * 
     * @param value
     *     allowed object is
     *     {@link TextWrapModeType }
     *     
     */
    public void setWordBreak(TextWrapModeType value) {
        this.wordBreak = value;
    }

    public boolean isSetWordBreak() {
        return (this.wordBreak!= null);
    }

    /**
     * Gets the value of the lineNumbers property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isLineNumbers() {
        if (lineNumbers == null) {
            return true;
        } else {
            return lineNumbers;
        }
    }

    /**
     * Sets the value of the lineNumbers property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setLineNumbers(boolean value) {
        this.lineNumbers = value;
    }

    public boolean isSetLineNumbers() {
        return (this.lineNumbers!= null);
    }

    public void unsetLineNumbers() {
        this.lineNumbers = null;
    }

    /**
     * Gets the value of the lineHeight property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLineHeight() {
        if (lineHeight == null) {
            return "12px";
        } else {
            return lineHeight;
        }
    }

    /**
     * Sets the value of the lineHeight property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLineHeight(String value) {
        this.lineHeight = value;
    }

    public boolean isSetLineHeight() {
        return (this.lineHeight!= null);
    }

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLanguage() {
        if (language == null) {
            return "";
        } else {
            return language;
        }
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLanguage(String value) {
        this.language = value;
    }

    public boolean isSetLanguage() {
        return (this.language!= null);
    }

    /**
     * Gets the value of the available property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAvailable() {
        if (available == null) {
            return "";
        } else {
            return available;
        }
    }

    /**
     * Sets the value of the available property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAvailable(String value) {
        this.available = value;
    }

    public boolean isSetAvailable() {
        return (this.available!= null);
    }

    /**
     * Gets the value of the relevance property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getRelevance() {
        if (relevance == null) {
            return  90;
        } else {
            return relevance;
        }
    }

    /**
     * Sets the value of the relevance property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRelevance(int value) {
        this.relevance = value;
    }

    public boolean isSetRelevance() {
        return (this.relevance!= null);
    }

    public void unsetRelevance() {
        this.relevance = null;
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/SyntaxHighlightType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p729701_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p909447_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;This element is used to configure language detection and the representation of syntax elements in recognized programming/script languages.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for SyntaxHighlightType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SyntaxHighlightType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="fontSize" type="{http://www.w3.org/2001/XMLSchema}string" default="10px" />
 *       <attribute name="fontOrigin" type="{http://schema.webpdf.de/1.0/operation}FontOriginModeType" default="system" />
 *       <attribute name="fontFamily" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="wordBreak" type="{http://schema.webpdf.de/1.0/operation}TextWrapModeType" default="auto" />
 *       <attribute name="lineNumbers" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="lineHeight" type="{http://www.w3.org/2001/XMLSchema}string" default="12px" />
 *       <attribute name="language" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="available" type="{http://www.w3.org/2001/XMLSchema}string" default="" />
 *       <attribute name="relevance" type="{http://www.w3.org/2001/XMLSchema}int" default="90" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SyntaxHighlightType")
public class SyntaxHighlightType {

    @XmlAttribute(name = "fontSize")
    protected String fontSize;
    @XmlAttribute(name = "fontOrigin")
    protected FontOriginModeType fontOrigin;
    @XmlAttribute(name = "fontFamily")
    protected String fontFamily;
    @XmlAttribute(name = "wordBreak")
    protected TextWrapModeType wordBreak;
    @XmlAttribute(name = "lineNumbers")
    protected Boolean lineNumbers;
    @XmlAttribute(name = "lineHeight")
    protected String lineHeight;
    @XmlAttribute(name = "language")
    protected String language;
    @XmlAttribute(name = "available")
    protected String available;
    @XmlAttribute(name = "relevance")
    protected Integer relevance;

    /**
     * Gets the value of the fontSize property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFontSize() {
        if (fontSize == null) {
            return "10px";
        } else {
            return fontSize;
        }
    }

    /**
     * Sets the value of the fontSize property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFontSize(String value) {
        this.fontSize = value;
    }

    public boolean isSetFontSize() {
        return (this.fontSize!= null);
    }

    /**
     * Gets the value of the fontOrigin property.
     * 
     * @return
     *     possible object is
     *     {@link FontOriginModeType }
     *     
     */
    public FontOriginModeType getFontOrigin() {
        if (fontOrigin == null) {
            return FontOriginModeType.SYSTEM;
        } else {
            return fontOrigin;
        }
    }

    /**
     * Sets the value of the fontOrigin property.
     * 
     * @param value
     *     allowed object is
     *     {@link FontOriginModeType }
     *     
     */
    public void setFontOrigin(FontOriginModeType value) {
        this.fontOrigin = value;
    }

    public boolean isSetFontOrigin() {
        return (this.fontOrigin!= null);
    }

    /**
     * Gets the value of the fontFamily property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFontFamily() {
        if (fontFamily == null) {
            return "";
        } else {
            return fontFamily;
        }
    }

    /**
     * Sets the value of the fontFamily property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFontFamily(String value) {
        this.fontFamily = value;
    }

    public boolean isSetFontFamily() {
        return (this.fontFamily!= null);
    }

    /**
     * Gets the value of the wordBreak property.
     * 
     * @return
     *     possible object is
     *     {@link TextWrapModeType }
     *     
     */
    public TextWrapModeType getWordBreak() {
        if (wordBreak == null) {
            return TextWrapModeType.AUTO;
        } else {
            return wordBreak;
        }
    }

    /**
     * Sets the value of the wordBreak property.
     * 
     * @param value
     *     allowed object is
     *     {@link TextWrapModeType }
     *     
     */
    public void setWordBreak(TextWrapModeType value) {
        this.wordBreak = value;
    }

    public boolean isSetWordBreak() {
        return (this.wordBreak!= null);
    }

    /**
     * Gets the value of the lineNumbers property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isLineNumbers() {
        if (lineNumbers == null) {
            return true;
        } else {
            return lineNumbers;
        }
    }

    /**
     * Sets the value of the lineNumbers property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setLineNumbers(boolean value) {
        this.lineNumbers = value;
    }

    public boolean isSetLineNumbers() {
        return (this.lineNumbers!= null);
    }

    public void unsetLineNumbers() {
        this.lineNumbers = null;
    }

    /**
     * Gets the value of the lineHeight property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLineHeight() {
        if (lineHeight == null) {
            return "12px";
        } else {
            return lineHeight;
        }
    }

    /**
     * Sets the value of the lineHeight property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLineHeight(String value) {
        this.lineHeight = value;
    }

    public boolean isSetLineHeight() {
        return (this.lineHeight!= null);
    }

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLanguage() {
        if (language == null) {
            return "";
        } else {
            return language;
        }
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLanguage(String value) {
        this.language = value;
    }

    public boolean isSetLanguage() {
        return (this.language!= null);
    }

    /**
     * Gets the value of the available property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAvailable() {
        if (available == null) {
            return "";
        } else {
            return available;
        }
    }

    /**
     * Sets the value of the available property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAvailable(String value) {
        this.available = value;
    }

    public boolean isSetAvailable() {
        return (this.available!= null);
    }

    /**
     * Gets the value of the relevance property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getRelevance() {
        if (relevance == null) {
            return  90;
        } else {
            return relevance;
        }
    }

    /**
     * Sets the value of the relevance property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRelevance(int value) {
        this.relevance = value;
    }

    public boolean isSetRelevance() {
        return (this.relevance!= null);
    }

    public void unsetRelevance() {
        this.relevance = null;
    }

}
